pub struct NullStateCatchup {
backoff: BackoffParams,
chain_configs: HashMap<Commitment<ChainConfig>, ChainConfig>,
}Expand description
Disable catchup entirely.
Fields
backoff: BackoffParamschain_configs: HashMap<Commitment<ChainConfig>, ChainConfig>Implementations
Sourceimpl NullStateCatchup
impl NullStateCatchup
Sourcepub fn add_chain_config(&mut self, cf: ChainConfig)
pub fn add_chain_config(&mut self, cf: ChainConfig)
Add a chain config preimage which can be fetched by hash during STF evaluation.
NullStateCatchup is used to disable catchup entirely when evaluating the STF, which
requires the ValidatedState to be pre-seeded with all
the dependencies of STF evaluation. However, the STF also depends on having the preimage of
various ChainConfig commitments, which are not stored in the
ValidatedState, but which instead must be supplied by a
separate preimage oracle. Thus, NullStateCatchup may be populated with a set of
ChainConfigs, which it can feed to the STF during evaluation.